# Webviz

Webviz is a static site generator that fascilitates producing visualizations
using [d3](https://d3js.org) and [plotly](https://plot.ly). Sites can be generated
both using markdown and the python interface. Visualizations and other page elements
can be added as plugins.

## History

Webviz (originally Webportal) was initially written and is maintained by
[Equinor ASA](http://www.equinor.com/) as a free visualization suite that can be
tailored to our needs, and as contribution to the free software community.

_This first initial release on pypi is just a placeholder. The first real deploy
will come from Travis and http://travis-ci.com/Statoil/webviz._
